### Usage

```js static
import InputFile from '@meta-vue/input-file';

export default {
	...
	components: { InputFile }
	...
};
```

### Example

```js
new Vue({
  data() {
    return {
      password: '',
      filesUploaded: []
    };
  },
  methods: {
    onValidation(validation, fieldName) {
      console.warn(`${fieldName} validation`, validation);
    }
  },
  template: `
    <span>
      <InputFile
      id="file1"
      label="Input file example"
      name="file1"
      v-model="filesUploaded"
      @validation="onValidation"
      :maxSize="3000"
      :accept="['image/jpeg']"
      >
      </InputFile>
      <h3 v-if="filesUploaded.length > 0">Files uploaded:</h3>
      <div v-for="(file, index) in filesUploaded" :key="index">
        <p>Name: {{file.name}} | Size: {{file.size}} | type: {{file.type}}</p>
      </div>
    </span>
  `
});
```

##### Example with custom slot
You can pass a custom slot to replace the default button for the component
```js
new Vue({
  data() {
    return {
      password: '',
      filesUploaded: []
    };
  },
  methods: {
    onValidation(validation, fieldName) {
      console.warn(`${fieldName} validation`, validation);
    }
  },
  template: `
    <span>
      <InputFile
      id="file1"
      label="Input file example with custom slot"
      name="file1"
      v-model="filesUploaded"
      @validation="onValidation"
      >
      <div style="color:green;background:#bdbdbd;cursor:pointer;">This is a custom upload html</div>
      </InputFile>
      <h3 v-if="filesUploaded.length > 0">Files uploaded:</h3>
      <div v-for="(file, index) in filesUploaded" :key="index">
        <p>Name: {{file.name}} | Size: {{file.size}} | type: {{file.type}}</p>
      </div>
    </span>
  `
});
```